@@ -3,8 +3,9 @@
   packageStartupMessage("                        Welcome to the package 'quarks'!")
   packageStartupMessage("********************************************************************************")
   packageStartupMessage("")
-  packageStartupMessage("Please report any possible errors and bugs to sebastian.letmathe@uni-paderborn.de.")
-  packageStartupMessage("Thank you.")
+  packageStartupMessage("Please report any possible errors and bugs to sebastian.let@t-online.de.")
+  packageStartupMessage("")
+  packageStartupMessage("                              Thank you.")
   packageStartupMessage("")
   packageStartupMessage("********************************************************************************")
 }
